@@ -40,7 +40,7 @@
 #' @seealso \code{\link{mark.wrapper}}
 #' @keywords utility
 #' @examples
-#' 
+#' \donttest{
 #' #
 #' # Compare this to the run.dipper shown under ?dipper
 #' # It is only necessary to create each parameter specification and 
@@ -94,7 +94,7 @@
 #'      return(dipper.results)
 #' }
 #' dipper.results=run.dipper()
-#' 
+#' }
 create.model.list<-function(model)
 {
 	parameters=setup.parameters(model,check=TRUE)
@@ -108,7 +108,8 @@ create.model.list<-function(model)
 				if(eval(parse(text=paste("is.list(",vec[i],")",sep="")),envir=parent.frame()))
 				{
 					if(eval(parse(text=paste("!is.null(",vec[i],"$formula)",sep="")),envir=parent.frame()) |
-							eval(parse(text=paste("!is.null(",vec[i],"[[1]]$formula)",sep="")),envir=parent.frame()))
+							(eval(parse(text=paste("is.list(",vec[i],"[[1]])",sep="")),envir=parent.frame())&&
+							eval(parse(text=paste("!is.null(",vec[i],"[[1]]$formula)",sep="")),envir=parent.frame())))
 						model.list[[n]]=c(model.list[[n]],vec[i])
 				}
 			}
