@@ -354,6 +354,8 @@
 #' @param parm.specific if TRUE, forces a link to be specified for each parameter
 #' @param mlogit0 if TRUE, any real parameter that is fixed to 0 and has an mlogit link will 
 #' have its link changed to logit so it can be simplified
+#' @param threads number of cpus to use with mark.exe if positive or number of cpus to remain idle if negative
+#' @param hessian if TRUE specifies to MARK to use hessian rather than second partial matrix
 #' @return model: a MARK object except for the elements \code{output} and
 #' \code{results}. See \code{\link{mark}} for a detailed description of the
 #' list contents.
@@ -364,7 +366,7 @@
 #' @keywords model
 #' @examples
 #' 
-#' 
+#' \donttest{
 #' data(dipper)
 #' #
 #' # Process data
@@ -401,9 +403,9 @@
 #'   parameters=list(Phi=Phidot,p=ptime))
 #' dipper.phiFlood.pdot=make.mark.model(dipper.processed,dipper.ddl,
 #'   parameters=list(Phi=PhiFlood, p=pdot))
-#' 
+#' }
 make.mark.model <-
-function(data,ddl,parameters=list(),title="",model.name=NULL,initial=NULL,call=NULL,default.fixed=TRUE,options=NULL,profile.int=FALSE,chat=NULL,simplify=TRUE,input.links=NULL,parm.specific=FALSE,mlogit0=FALSE)
+function(data,ddl,parameters=list(),title="",model.name=NULL,initial=NULL,call=NULL,default.fixed=TRUE,options=NULL,profile.int=FALSE,chat=NULL,simplify=TRUE,input.links=NULL,parm.specific=FALSE,mlogit0=FALSE,threads=-1,hessian=FALSE)
 {
 
 #  *******************  INTERNAL FUNCTIONS    *********************************
@@ -728,14 +730,42 @@ for (i in 1:length(parameters)) {
      }
 }
 #
-# Look for setting of initial values in the input file; if found write them out
-# as is to new input file.  Simplifying the PIM structure does not change the
-# column structure of the design matrix and therefore does not change the
-# definition of the betas.
+# Next compute the new simplified design matrix.  rownums is the row numbers (indices)
+# from the original design matrix but there is only one for each of the new
+# parameters with indices 1:length(new.indices).  The new design matrix
+# (complete.design.matrix) is obtained by subsetting the rows from the
+# original design matrix matching rownums.  This is done using row.names to be
+# able to use subset so it will always yield a dataframe.  Using indices for
+# row numbers can result in a vector if there is only a single beta.
+rownums=match(1:length(unique(new.indices)),new.indices)
+# 22-Aug-05; change to use [rownums,] to accomodate fixed parameters
+# 1 feb 06; modified to cope with single element selected
+if(length(rownums)==1)
+	complete.design.matrix=subset(model$design.matrix,1:dim(model$design.matrix)[1]%in%rownums)
+else
+	complete.design.matrix=model$design.matrix[rownums,,drop=FALSE]
+#
+# Find any columns that are all 0; left from mlogit0 fix
+#
+dm=complete.design.matrix
+allzero=apply(dm,2,function(x) all(x=="0"))
+complete.design.matrix=dm[,!allzero,drop=FALSE]
+#
+# Look for setting of initial values in the input file; if found write them 
+# exclude columns that are now all 0s.
 #
 if(length(grep("initial ",model$input))!=0)
 {
-  string=model$input[grep("initial ",model$input)]
+  if(any(allzero))
+  {
+	  initial=strsplit(model$input[grep("initial ", model$input)]," ")[[1]]
+	  initial=initial[-c(1:2,length(initial))]
+	  initial=initial[!allzero]
+	  string=paste("initial ",paste(initial,collapse=" ")," ;",collapse=" ")
+  } else
+  {
+	  string=model$input[grep("initial ",model$input)]
+  }		
   write(string, file = outfile, append = TRUE)
 }
 #
@@ -761,21 +791,6 @@ else
       write(paste(string,";",sep=""),file=outfile,append=TRUE)      
     } 
 }
-#
-# Next output the new simplified design matrix.  rownums is the row numbers (indices)
-# from the original design matrix but there is only one for each of the new
-# parameters with indices 1:length(new.indices).  The new design matrix
-# (complete.design.matrix) is obtained by subsetting the rows from the
-# original design matrix matching rownums.  This is done using row.names to be
-# able to use subset so it will always yield a dataframe.  Using indices for
-# row numbers can result in a vector if there is only a single beta.
-rownums=match(1:length(unique(new.indices)),new.indices)
-# 22-Aug-05; change to use [rownums,] to accomodate fixed parameters
-# 1 feb 06; modified to cope with single element selected
-if(length(rownums)==1)
-   complete.design.matrix=subset(model$design.matrix,1:dim(model$design.matrix)[1]%in%rownums)
-else
-   complete.design.matrix=model$design.matrix[rownums,,drop=FALSE]
 # 10 Jan 06; change to accomodate S(.) with known fate where design matrix can
 # become a single element with simplification
 #if(is.vector(complete.design.matrix))
@@ -874,7 +889,10 @@ create.pim=function(nocc,parameters,npar,mixtures)
                   if(parameters$pim.type=="time")
                       mat=rbind(mat,c(rep(0,k-1),(npar+k-1):(npar+k-1+ncol-1)))
                   else
-                      mat=rbind(mat,c(rep(0,k-1),rep(npar,ncol)))
+					  if(parameters$pim.type=="age")
+						  mat=rbind(mat,c(rep(0,k-1),npar:(npar+ncol-1)))
+					  else
+						  mat=rbind(mat,c(rep(0,k-1),rep(npar,ncol)))
                }
                ncol=ncol-1
 		   }
@@ -1107,14 +1125,35 @@ create.agenest.var=function(data,init.agevar,time.intervals)
          }
      }
   }
+# 
+#  Unless this is nest data, aggregate data
+#
+  if(!is.null(covariates))
+	    zzd=data.frame(cbind(zz,data$data[,covariates]))
+  else
+	    zzd=zz
+  accumulate=TRUE
+  if(etype!="Nest" & accumulate)
+  {
+	  pasted.data=apply(zzd, 1, paste, collapse = "")
+	  ng=ncol(data$freq)
+	  if(ng>1)
+		  freq=t(sapply(split(data$freq,pasted.data ),colSums))
+	  else
+		  freq=sapply(split(data$freq, pasted.data),sum)
+	  zzd=unique(zzd[order(pasted.data),])
+	  zzd[,2:(1+ng)]=freq
+	  zz=zzd[,1:(ng+1)]
+  }
 #
 # Output title and list of covariates
 # 11 Jan 06; Added code for multistratum - nstrata and strata labels
 #
+
   if(is.null(nocc.secondary))
-     string=paste("proc title ",title,";\nproc chmatrix occasions=",nocc," groups=",number.of.groups," etype=",etype)
+     string=paste("proc title ",title,";\nproc chmatrix occasions=",nocc," groups=",number.of.groups," etype=",etype, "Threads=", threads)
   else
-     string=paste("proc title ",title,";\nproc chmatrix occasions=",sum(nocc.secondary)," groups=",number.of.groups," etype=",etype)
+     string=paste("proc title ",title,";\nproc chmatrix occasions=",sum(nocc.secondary)," groups=",number.of.groups," etype=",etype, "Threads=", threads)
   if(model.list$strata)string=paste(string," strata=",data$nstrata,sep="")
   if(!is.null(covariates))
   {
@@ -1129,7 +1168,7 @@ create.agenest.var=function(data,init.agevar,time.intervals)
 	  string=paste(string," mixtures =",length(levels(ddl$p$time)))
   time.int=data$time.intervals
   if(!is.null(data$reverse) &&(data$reverse | data$model=="MultScalOcc")) time.int[time.int==0]=1
-  string=paste(string," ICMeans NoHist hist=",dim(zz)[1],
+  string=paste(string," ICMeans NoHist hist=",nrow(zz),
            ";\n time interval ",paste(time.int,collapse=" "),";")
   if(model.list$strata)string=paste(string,"\n strata=",paste(data$strata.labels[1:data$nstrata],collapse=" "),";",sep="")
   if(!is.null(covariates))
@@ -1144,7 +1183,8 @@ create.agenest.var=function(data,init.agevar,time.intervals)
         if(any(any.na))
            stop(paste("The following individual covariates are not allowed because they contain NA: ",paste(names(data$data[,covariates,drop=FALSE])[any.na],collapse=",")))
         else
-           zz=data.frame(cbind(zz,data$data[,covariates]))
+            zz=zzd
+#           zz=data.frame(cbind(zz,data$data[,covariates]))
      }
   }
   write(string,file=outfile)
@@ -1217,8 +1257,11 @@ create.agenest.var=function(data,init.agevar,time.intervals)
 #
 # Next output proc Estimate 
 #
-  string=paste(paste("proc estimate link=",spell(link),sep=""),"NOLOOP varest=2ndPart ",options," ;\nmodel={",model.name,"};")
-  write(string,file=outfile,append=TRUE)
+  if(!hessian)
+     string=paste(paste("proc estimate link=",spell(link),sep=""),"NOLOOP varest=2ndPart ",options," ;\nmodel={",model.name,"};")
+  else
+     string=paste(paste("proc estimate link=",spell(link),sep=""),"NOLOOP varest=Hessian ",options," ;\nmodel={",model.name,"};")
+ write(string,file=outfile,append=TRUE)
 #
 # Next compute PIMS for each parameter in the model - these are the all different PIMS
 # 11 Jan 06 code added for multistrata models
@@ -1619,7 +1662,8 @@ create.agenest.var=function(data,init.agevar,time.intervals)
             {
                 if(length(names(initial))==0)
 				{
-				  cat("\nLength of initial vector doesn't match design matrix\n")
+				  cat("\nLength of initial vector doesn't match design matrix: ",ncol(complete.design.matrix)," \n")
+				  print(colnames(complete.design.matrix))
                   stop()
 			    }else
 				{
@@ -1702,7 +1746,6 @@ create.agenest.var=function(data,init.agevar,time.intervals)
                  {
 				    if(parx %in% c("pi","Omega"))
 				    {
-#					    nsets=length(pim[[parx]])
 					    for (kk in 1:number.of.groups)
 					    {
 					   	     logit.numbers=max.logit.number+rep(1:(nrow(full.ddl[[parx]])/(number.of.groups*(nstrata-1))),nstrata-1)
@@ -1813,7 +1856,6 @@ create.agenest.var=function(data,init.agevar,time.intervals)
 # Check to make sure that the only rows in the design matrix that are all zeros are
 # ones that correspond to fixed parameters.
 #
-
   if(simplify)
   {                               
       dm=model$simplify$design.matrix
